import { Renderer } from './renderer/renderer';
/**
 * Set the quality of rendering based on FPS values.
 *
 * When using this the size of the canvas must be fixed with CSS.
 *
 * The `addDeltaTime` method should be called once every frame.
 *
 * Usage:
 * ```js
 *  const renderer = await compile(...);
 *  const autoscaler = new FpsQualityAutoscaler(renderer);
 * ```
 */
export declare class FpsQualityAutoscaler {
    private readonly renderer;
    private readonly maxAdjustmentRateInMilliseconds;
    private readonly adjustmentRateIncrease;
    private adjustmentRateInMilliseconds;
    private fps;
    static fpsTarget: number;
    fpsHysteresis: number;
    constructor(renderer: Renderer);
    get FPS(): number;
    private deltaTimes;
    private deltaTimeSinceLastAdjustment;
    /**
     * Autoscaling is also done by calling this function
     * @param deltaTimeInMilliseconds
     */
    addDeltaTime(deltaTimeInMilliseconds: DOMHighResTimeStamp): void;
    private calculateFPS;
    private distanceScale;
    private lightsScale;
    private adjustQuality;
}
//# sourceMappingURL=fps-quality-autoscaler.d.ts.map