import { ReadonlyVec2, vec2 } from 'gl-matrix';
import { Drawable } from '../../../drawables/drawable';
import { DrawableDescriptor } from '../../../drawables/drawable-descriptor';
import { RuntimeSettings } from '../settings/runtime-settings';
import { StartupSettings } from '../settings/startup-settings';
import { Renderer } from './renderer';
import { RendererInfo } from './renderer-info';
/** @internal */
export declare class ContextAwareRenderer implements Renderer {
    private canvas;
    private descriptors;
    private settingsOverrides;
    private renderer;
    private isRendererReady;
    private readyPromise;
    private runtimeOverrides;
    private ignoreWebGL2?;
    private previousViewAreaTopLeft?;
    private previousViewAreaSize?;
    private contextRestoredHandler;
    private contextLostHandler;
    constructor(canvas: HTMLCanvasElement, descriptors: Array<DrawableDescriptor>, settingsOverrides: Partial<StartupSettings>);
    get initializedPromise(): Promise<void>;
    private createRenderer;
    private waitForRenderer;
    private handleContextLost;
    private handleContextRestored;
    private handle;
    get canvasSize(): ReadonlyVec2;
    get viewAreaSize(): ReadonlyVec2;
    get insights(): RendererInfo | null;
    setViewArea(topLeft: ReadonlyVec2, size: ReadonlyVec2): void;
    setRuntimeSettings(overrides: Partial<RuntimeSettings>): void;
    addDrawable(drawable: Drawable): void;
    displayToWorldCoordinates(displayCoordinates: ReadonlyVec2): vec2;
    worldToDisplayCoordinates(worldCoordinates: ReadonlyVec2): vec2;
    renderDrawables(): void;
    destroy(): void;
}
//# sourceMappingURL=context-aware-renderer.d.ts.map