import { ReadonlyVec2, vec2 } from 'gl-matrix';
import { Drawable } from '../../../drawables/drawable';
import { DrawableDescriptor } from '../../../drawables/drawable-descriptor';
import { RuntimeSettings } from '../settings/runtime-settings';
import { StartupSettings } from '../settings/startup-settings';
import { Renderer } from './renderer';
import { RendererInfo } from './renderer-info';
/** @internal */
export declare class RendererImplementation implements Renderer {
    private readonly canvas;
    private readonly descriptors;
    private readonly gl;
    private readonly uniformsProvider;
    private readonly distanceFieldFrameBuffer;
    private readonly distancePass;
    private readonly lightingFrameBuffer;
    private readonly lightsPass;
    private stopwatch?;
    private textures;
    private palette;
    private _canvasSize;
    private blendFactor;
    private canvasResizeObserver;
    private applyRuntimeSettings;
    setRuntimeSettings(overrides: Partial<RuntimeSettings>): void;
    constructor(canvas: HTMLCanvasElement, descriptors: Array<DrawableDescriptor>, ignoreWebGL2?: boolean);
    private applyCanvasResizeObserver;
    initialize(settingsOverrides: Partial<StartupSettings>): Promise<void>;
    get insights(): RendererInfo;
    private setTextures;
    private static hasSdf;
    addDrawable(drawable: Drawable): void;
    renderDrawables(): void;
    displayToWorldCoordinates(displayCoordinates: ReadonlyVec2): vec2;
    worldToDisplayCoordinates(worldCoordinates: ReadonlyVec2): vec2;
    setViewArea(topLeft: ReadonlyVec2, size: ReadonlyVec2): void;
    get viewAreaSize(): ReadonlyVec2;
    get canvasSize(): ReadonlyVec2;
    destroy(): void;
}
//# sourceMappingURL=renderer-implementation.d.ts.map